@@ -1,3 +1,4 @@
+from __future__ import annotations
 """
 Helper functions that handle high-level operations and translating asynchronous requests for easy development.
 """
@@ -133,7 +134,7 @@ asyncio.run(work(img, tiles, res_lvl, dims))
         # set res and get default res level if necessary
         if resLvl is None:
             resLvl = await rps.getResolutionLevels()
-        await rps.setResolutionLevel(resLvl)
+        await rps.setResolutionLevel(resLvl-1)
 
         # request and return tiles
         i=1
@@ -151,7 +152,7 @@ asyncio.run(work(img, tiles, res_lvl, dims))
 
     # create parallel raw pixels stores
     jobs=[]
-    for chunk in chunkify(tiles, PARALLEL_STORE_COUNT):
+    for chunk in chunkify(tiles, int(len(tiles)/PARALLEL_STORE_COUNT)):
         jobs.append(work(img.getPrimaryPixels().getId(), chunk, resLvl))
     return merge_async_iters(*jobs)
 
@@ -520,8 +521,8 @@ Returns
 list
     List of (z,c,t,(x,y,w,h)) tiles for use in getTiles.
     """
-    width = range(img.getSizeX())
-    height = range(img.getSizeY())
+    width = img.getSizeX()
+    height = img.getSizeY()
     z_indexes = range(img.getSizeZ())
     timepoints = range(img.getSizeT())
     channels = range(img.getSizeC())
